pub struct Actor {
pub name: String,
pub kind: ActorKind,
}Expand description
The actor a workspace attributes its snapshots and journal entries to.
Fields
name: StringThe actor’s display name, as it appears in the journal.
kind: ActorKindWhat kind of actor this is.